""" Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """

import os
import json
from abc import ABC, abstractmethod
from constants import *
from framework.utility.task_utils import TaskUtilities
from framework.utility.config import Config


class Tasks(ABC):
    def __init__(self) -> None:
        self.task_utilities = TaskUtilities()
        self.config = Config.get_config()

    @property
    @abstractmethod
    def tags(self) -> str:
        pass

    @property
    def current_version(self) -> str:
        current_version = self.task_utilities.get_current_version()
        return current_version

    @property
    def target_upgrade_version(self) -> str:
        target_upgrade_version = self.task_utilities.get_target_version()
        return target_upgrade_version

    @abstractmethod
    def get_description(self) -> str:
        pass

    @abstractmethod
    def is_supported(self) -> bool:
        pass

    @abstractmethod
    def execute(self):
        pass

    @abstractmethod
    def validate(self) -> bool:
        pass

    def store_result_to_json(self, json_file_path, phase_name, task_name, key=None, data=None) -> None:
        self.task_utilities.store_result_to_json(
            json_file_path, phase_name, task_name, key, data)

    def get_step_results(self, phase_name, task_name) -> dict:
        step_results_json_path = STEP_RESULT_FILE.format(
            self.target_upgrade_version)
        if os.path.exists(step_results_json_path):
            with open(step_results_json_path, 'r') as json_file:
                json_object = json.load(json_file)
                return json_object[phase_name][task_name]
        else:
            return {}

    def print_txt(self, txt):
        self.task_utilities.print_justified_text(txt)
