""" Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """
import yaml
from constants import *


class Config(object):
    @staticmethod
    def _read_properties_file(properties_file_path):
        config = {}
        separators = ['=', ':', ' ']
        with open(properties_file_path, 'r') as properties_file:
            for line in properties_file:
                strip_line = line.strip()
                if strip_line.startswith('#'):
                    continue
                if '#' in strip_line:
                    strip_line = strip_line.split('#', 1)[0].strip()
                for separator in separators:
                    if separator in strip_line:
                        key_value = strip_line.split(separator, 1)
                        key = key_value[0].strip()
                        value = key_value[1].strip()
                        config[key] = value
                        break
        return config

    @staticmethod
    def _read_yaml_file(yaml_file_path):
        config = {}
        with open(yaml_file_path, 'r') as yaml_file:
            config.update(yaml.safe_load(yaml_file))
        return config

    @staticmethod
    def get_config(option=None, fallback=None):
        config = {}
        for properties_file in CONFIG_FILES_PROPERTIES:
            config.update(Config._read_properties_file(properties_file))
        for yaml_file in CONFIG_FILES_YAML:
            config.update(Config._read_yaml_file(yaml_file))

        if not option and not fallback:
            return config

        if option:
            try:
                return config.get(option, fallback)
            except Exception as ex:
                return fallback
        return fallback
