""" Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """

import os
import shlex
import subprocess
from helpers.logger import Logger
from framework.utility import messages


class CmdUtils(object):
    def __init__(self) -> None:
        self.logger = Logger.get_logger(__name__)

    def execute_cmd(self, command, trap_output=False) -> dict:
        '''This function is responsible for executing cli commands'''
        
        cmd = shlex.split(command)
        ret_dict = dict()
        std_out = None
        std_err = None
        return_code = None
        try:
            print("Executing command...")
            result = subprocess.run(args=cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
            
            std_out = result.stdout.decode()
            std_err = result.stderr
            if isinstance(std_err, tuple):
                std_err = std_err[1]
            std_err = std_err.decode()
            return_code = 1 if result.returncode != 0 else result.returncode

            if std_err:
                self.logger.error(std_err)
        except Exception as ex:
            err_msg = messages.ERROR_OCCURED.format(
                f"execution of {command} command", ex)
            self.logger.exception(err_msg)
            ret_dict['return_code'] = return_code
            ret_dict['std_out'] = std_out
            ret_dict['std_err'] = std_err
            return ret_dict

        if not trap_output:
            print(std_out)
        
        ret_dict['return_code'] = return_code
        ret_dict['std_out'] = std_out
        ret_dict['std_err'] = std_err
        return ret_dict
    