""" Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """

import logging
import os
import sys
from framework.utility.config import Config
from framework.utility import messages


class Logger(object):

    @staticmethod
    def get_logger(name):
        logger_config = Config.get_config()
        logger = logging.getLogger(name)

        target_upgrade_version = None
        try:
            if len(sys.argv) > 1 and '--version' in sys.argv:
                version_arg_index = sys.argv.index('--version')+1
                target_upgrade_version = sys.argv[version_arg_index]
        except IndexError as indexErr:
            print(messages.VERSION_ARG_NOT_PROVIDED)
            sys.exit()
        additional_format = {"target_upgrade_version": target_upgrade_version}

        if not logger.hasHandlers():
            logger.setLevel(logger_config.get('log_level'))
            log_file_path = logger_config.get('log_path')
            if not os.path.exists(log_file_path):
                open(log_file_path, 'x')
            logger_handler = logging.FileHandler(logger_config.get('log_path'))
            logger_handler.setLevel(logging.DEBUG)

            logger_formatter = logging.Formatter(
                '%(asctime)s [%(target_upgrade_version)s] %(levelname)s %(module)s: %(funcName)s(): %(lineno)d: %(message)s',
                datefmt='%Y-%m-%d,%H:%M:%S'
            )
            logger_handler.setFormatter(logger_formatter)
            logger.handlers = []
            logger.addHandler(logger_handler)

        logger = logging.LoggerAdapter(logger, additional_format)
        return logger
