#!/bin/bash -ex
# Copyright start
# Copyright (C) 2008 - 2024 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end

usage(){
    echo "usage: $0 <options>
    OPTIONS:
    -o    Git repository name
          Ex: certs

    -v    Release version.
          Ex: 4.11.1

    -b    Build number.
          Ex: 99

    -s    Directory path containing this source.
          Ex: /home/src

    -d    Install log directory.
          Ex: /var/log/cyops

    -f    Install log file.
          Ex: 4.11.1-34.log

    -r    Directory path in which to put created rpm.
          Ex: /home/src/rpms

    -p    Package name
          Ex: cyops-certs

    -a    RPM Buildarea. Temporary work folder required by rpmbuild.
          Ex: /home/buildarea"
}

process_parameters(){
    while getopts p:v:b:s:d:f:r:a:o: o;do
        case "$o" in
            o) git_repo=$OPTARG;;

            p) pkg_name=$OPTARG;;

            v) release_version=$OPTARG;;

            b) build_number=$OPTARG;;

            s) src=$OPTARG;;

            d) install_log_dir=$OPTARG;;

            f) install_log_file=$OPTARG;;

            r) rpms_dir=$OPTARG;;

            a) buildarea=$OPTARG;;
    	esac
    done

    if [[ -z "$release_version" || -z "$build_number" || -z "$install_log_dir" || \
          -z "$install_log_file" || -z "$src" || -z "$rpms_dir" || -z "$pkg_name" || \
          -z "$buildarea" || -z "$git_repo" ]]; then
    	usage
    	exit 1 ;
    fi
}

########
# MAIN #
########
process_parameters $@

# Source common functions and variables
. $src/DevOps/builds/common/functions-lib.sh

copy_to_temp(){
    cp -R $src/$git_repo/config ${tmp_tar_dir}/
    cp -R $src/$git_repo/framework ${tmp_tar_dir}/
    cp -R $src/$git_repo/helpers ${tmp_tar_dir}/
    cp -R $src/$git_repo/outputs ${tmp_tar_dir}/
    cp -R $src/$git_repo/rpm ${tmp_tar_dir}/
    cp -R $src/$git_repo/templates ${tmp_tar_dir}/
    cp -R $src/$git_repo/workflow ${tmp_tar_dir}/
    cp $src/$git_repo/constants.py ${tmp_tar_dir}/
    cp $src/$git_repo/main.py ${tmp_tar_dir}/
    cp $src/$git_repo/requirements.txt ${tmp_tar_dir}/
}

prep

build_rpm
